@@ -1,12 +1,11 @@
 """ Main module for the Discord bot application. """
 
 import sys
-from typing import Callable, Optional, Sequence, Type
+from typing import Optional, Sequence, Type
 
 from spectra_lexer import Spectra, SpectraOptions
 from spectra_lexer.console.system import SystemConsole
 from spectra_lexer.qt.svg import SVGRasterEngine
-from spectra_lexer.resource.rules import StenoRule
 from spectra_lexer.spc_board import BoardDiagram, BoardEngine
 from spectra_lexer.spc_lexer import StenoAnalyzer, TranslationPairs
 from spectra_lexer.spc_search import SearchEngine
@@ -38,14 +37,13 @@ class DiscordApplication:
     """ Spectra engine application that accepts string input from Discord users. """
 
     def __init__(self, search_engine:SearchEngine, analyzer:StenoAnalyzer,
-                 board_engine:BoardEngine, msg_factory:MessageFactory, log:Callable[[str], None], *,
+                 board_engine:BoardEngine, msg_factory:MessageFactory, *,
                  query_max_chars:int=None, query_trans:dict=None, search_depth=1, board_AR:float=None) -> None:
         self._search_engine = search_engine
         self._analyzer = analyzer
         self._board_engine = board_engine
         self._text_message = msg_factory.text_message
         self._board_message = msg_factory.board_message
-        self._log = log                          # Thread-safe logger.
         self._query_max_chars = query_max_chars  # Optional limit for # of characters allowed in a user query string.
         self._query_trans = query_trans or {}    # Translation table to remove characters before searching for words.
         self._search_depth = search_depth        # Maximum number of search results to analyze at once.
@@ -85,18 +83,14 @@ class DiscordApplication:
                 word = "-" * len(word)
             yield keys, word + " "
 
-    def _analyze_all(self, translations:TranslationPairs) -> StenoRule:
-        """ Create a compound rule from each strokes/word pair we found. """
-        return self._analyzer.compound_query(translations)
-
     def _query_text(self, text:str) -> DiscordMessage:
-        """ Parse a user query string as English text. """
+        """ Parse a user query string as English text and make diagrams from each strokes/word pair we find. """
         show_letters = not text.startswith('+')
         letters = text.translate(self._query_trans)
         translations = list(self._search_words(letters))
         if not any([k for k, w in translations]):
             return self._text_message('No suggestions.')
-        analysis = self._analyze_all(translations)
+        analysis = self._analyzer.compound_query(translations)
         caption = str(analysis)
         board_data = self._board_engine.draw_rule(analysis, aspect_ratio=self._board_AR, show_letters=show_letters)
         return self._board_message(caption, board_data)
@@ -128,24 +122,12 @@ class DiscordApplication:
         console.repl()
         return 0
 
-    def run_bot(self, token:str, cmd_name="spectra") -> int:
-        """ Run the application as a Discord bot. """
-        if not token:
-            self._log("No token given. Opening test console...")
-            return self.run_console()
-        bot = DiscordBot(token, self._log)
-        bot.add_command(cmd_name, self.query)
-        self._log("Discord bot started.")
-        return bot.run()
-
 
 def build_app(spectra:Spectra) -> DiscordApplication:
     io = spectra.resource_io
     search_engine = spectra.search_engine
     analyzer = spectra.analyzer
     board_engine = spectra.board_engine
-    log = spectra.logger.log
-    log("Loading...")
     svg_engine = SVGRasterEngine(background_rgba=(0, 0, 0, 0))
     msg_factory = MessageFactory(svg_engine=svg_engine)
     excluded_chars = r'''#$%&()*+-,.?!/:;<=>@[\]^_`"{|}~'''
@@ -155,16 +137,26 @@ def build_app(spectra:Spectra) -> DiscordApplication:
     stripped_values = [v.strip(' {<&>}') for v in translations.values()]
     translations = {k: v for k, v in zip(translations, stripped_values) if v}
     search_engine.set_translations(translations)
-    return DiscordApplication(search_engine, analyzer, board_engine, msg_factory, log,
+    return DiscordApplication(search_engine, analyzer, board_engine, msg_factory,
                               query_max_chars=100, query_trans=map_to_space, search_depth=3, board_AR=1.5)
 
 
 def main() -> int:
+    """ Run the application as a Discord bot. """
     opts = SpectraOptions("Run Spectra as a Discord bot.")
     opts.add("token", "", "Discord bot token (REQUIRED).")
-    spectra = Spectra.compile(opts)
+    opts.add("command", "spectra", "!command string for Discord users.")
+    spectra = Spectra(opts)
+    log = spectra.logger.log
+    log("Loading Discord bot...")
     app = build_app(spectra)
-    return app.run_bot(opts.token)
+    if not opts.token:
+        log("No token given. Opening test console...")
+        return app.run_console()
+    bot = DiscordBot(opts.token, log)
+    bot.add_command(opts.command, app.query)
+    log("Discord bot started.")
+    return bot.run()
 
 
 if __name__ == '__main__':
