@@ -1,7 +1,7 @@
 function SpectraClient() {
 
     const TR_DELIM = '->';          // Delimiter between keys and letters of translations shown in title bar.
-    const MORE_TEXT = '(more...)';  // Text displayed as the final match, allowing the user to expand the search.
+    const MORE_TEXT = '[more...]';  // Text displayed as the final match, allowing the user to expand the search.
 
     const NODE_SELECTOR = '.stenoGraph a';             // CSS selector for graph nodes.
     const OPT_SELECTOR = 'input[name="w_boardopts"]';  // CSS selector for board option radio elements.
@@ -177,13 +177,9 @@ function SpectraClient() {
         return false;
     });
 
-    function updateSearch({matches, is_complete}) {
+    function updateSearch(matches) {
         lastMatches = matches;
         let keys = Object.keys(matches);
-        // If there are unseen results, add a final list item to allow search expansion.
-        if(!is_complete) {
-            keys.push(MORE_TEXT);
-        }
         matchSelector.update(keys);
         // If the new list does not have the previous selection, reset the mappings.
         if(!matchSelector.value) {
